@@ -16,6 +16,7 @@ test_that("mnar() warns users of non-numeric encoding", {
 })
 
 test_that("mnar() calculates correct MCAR statistics", {
+  testthat::skip_on_cran()
   output <- mnar(companydata)
   expect_equal(output$mcar$statistic, 22.6702661)
   expect_equal(output$mcar$degrees_freedom, 11)
@@ -23,22 +24,18 @@ test_that("mnar() calculates correct MCAR statistics", {
   expect_equal(output$mcar$missing_patterns, 4)
 })
 
+
 test_that("mnar() calculates correct MAR statistics", {
+  testthat::skip_on_cran()
   output <- mnar(companydata)
   expect_equal(output$mar$missing, c("product_rating", "employees"))
-  expect_equal(
-    output$mar$p_value,
-    c(0.11, 0.01),
-    tolerance = 1e-1
-  )
+  expect_equal(output$mar$p_value, c(0.11, 0.01), tolerance = 1e-1)
   expect_equal(output$mar$explanatory, c("product_rating", "gross_profit"))
-  expect_equal(
-    output$mar$p_values$product_rating,
+  expect_equal(output$mar$p_values$product_rating,
     c(0.61, 0.93, 0.11, 0.76, 0.26),
     tolerance = 1e-1
   )
-  expect_equal(
-    output$mar$p_values$employees,
+  expect_equal(output$mar$p_values$employees,
     c(0.89, 0.01, 0.80, 0.86, 0.01),
     tolerance = 1e-1
   )
